# Generated by Django 5.2.9 on 2025-12-16 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wbhuman_resources', '0023_alter_employeehumanresource_weekly_off_periods'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='absencerequestperiods',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='balancehourlyallowance',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='dayoffcalendar',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='employeeweeklyoffperiods',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='employeeyearbalance',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='balancehourlyallowance',
            constraint=models.UniqueConstraint(fields=('balance', 'period_index'), name='unique_balanceallowance'),
        ),
        migrations.AddConstraint(
            model_name='dayoffcalendar',
            constraint=models.UniqueConstraint(fields=('resource', 'timezone'), name='unique_calendar'),
        ),
        migrations.AddConstraint(
            model_name='employeeweeklyoffperiods',
            constraint=models.UniqueConstraint(fields=('employee', 'period', 'weekday'), name='unique_weeklyoffperiod'),
        ),
        migrations.AddConstraint(
            model_name='employeeyearbalance',
            constraint=models.UniqueConstraint(fields=('employee', 'year'), name='unique_employeeyearbalance'),
        ),
    ]
