# Generated by Django 4.2.9 on 2024-02-20 10:08

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wbhuman_resources", "0018_remove_position_group_position_groups"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="absencerequest",
            options={
                "permissions": [("administrate_absencerequest", "Can Administrate Absence Requests")],
                "verbose_name": "Absence Request",
                "verbose_name_plural": "Absence Requests",
            },
        ),
        migrations.AlterModelOptions(
            name="kpi",
            options={
                "permissions": [("administrate_kpi", "Can Administrate KPI")],
                "verbose_name": "Key Performance Indicator",
                "verbose_name_plural": "Key Performance Indicators",
            },
        ),
        migrations.AlterModelOptions(
            name="review",
            options={
                "permissions": [("administrate_review", "Can Administrate Reviews")],
                "verbose_name": "Review",
                "verbose_name_plural": "Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="employeehumanresource",
            options={
                "permissions": [("administrate_employeehumanresource", "Can administrate Employee Human Resource")],
                "verbose_name": "Employee Human Resource",
                "verbose_name_plural": "Employee Human Resources",
            },
        ),
    ]
