from .absence import (
    ABSENCEPLANNER_MENUITEM,
    ABSENCEREQUEST_MENUITEM,
    ABSENCEREQUESTTYPE_MENUITEM,
    ABSENCETABLE_MENUITEM,
)
from .administration import ADMINISTRATION_MENU
from .calendars import DAYOFF_MENUITEM, DAYOFFCALENDAR_MENUITEM
from .employee import (
    EMPLOYEE_MENUITEM,
    EMPLOYEEHUMANRESOURCE_MENUITEM,
    POSITION_MENUITEM,
)
from .kpis import KPI_MENUITEM, KPIEVALUATIONPANDAS_MENUITEM
from .review import (
    REVIEW_MENUITEM,
    REVIEWANDWER_MENUITEM,
    REVIEWGROUP_MENUITEM,
    REVIEWQUESTION_MENUITEM,
    REVIEWQUESTIONCATEFORY_MENUITEM,
    REVIEWTEMPLATE_MENUITEM,
)
